xAnno
a GRanges / GRangesList / TxDb object, with its first meta column to represent the possible type of the range; Or a list object with named initial value vectors matching required parameters for a specific soj.type
soj.type
type of the sojourn distribution, following types are supported: 'gamma', 'pois', 'nbinom'